==> vacuum-1.0.1-source.tar.gz: vacuum-1.0.1/src/translations/ru_RU/xmppstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>XmppStream</name>
    <message>
        <source>Password request</source>
        <translation>Запрос пароля</translation>
    </message>
    <message>
        <source>Enter password for &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Введите пароль для &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Connection not specified</source>
        <translation>Соединение не определено</translation>
    </message>
    <message>
        <source>XMPP connection timed out</source>
        <translation>Превышено время установки XMPP соединения</translation>
    </message>
    <message>
        <source>Wrong XMPP stream negotiation response</source>
        <translation>Неверный ответ при инициализации XMPP потока</translation>
    </message>
</context>
<context>
    <name>XmppStreams</name>
    <message>
        <source>Bad Request Format</source>
        <translation>Неверный формат запроса</translation>
    </message>
    <message>
        <source>Bad Namespace Prefix</source>
        <translation>Неверный префикс пространства имён</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Конфликт</translation>
    </message>
    <message>
        <source>Connection timeout</source>
        <translation>Превышено время ожидания соединения</translation>
    </message>
    <message>
        <source>Host Gone</source>
        <translation>Хост недоступен</translation>
    </message>
    <message>
        <source>Host Unknown</source>
        <translation>Неизвестный хост</translation>
    </message>
    <message>
        <source>Improper Addressing</source>
        <translation>Неправильная адресация</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <source>Invalid From</source>
        <translation>Недопустимый отправитель</translation>
    </message>
    <message>
        <source>Invalid Id</source>
        <translation>Недопустимый ID</translation>
    </message>
    <message>
        <source>Invalid Namespace</source>
        <translation>Недопустимое пространство имён</translation>
    </message>
    <message>
        <source>Invalid XML</source>
        <translation>Недопустимый XML</translation>
    </message>
    <message>
        <source>Not Authorized</source>
        <translation>Не авторизован</translation>
    </message>
    <message>
        <source>Policy Violation</source>
        <translation>Нарушение правил</translation>
    </message>
    <message>
        <source>Remote Connection Failed</source>
        <translation>Сбой удаленного соединения</translation>
    </message>
    <message>
        <source>Resource Constraint</source>
        <translation>Ограничение ресурса</translation>
    </message>
    <message>
        <source>Restricted XML</source>
        <translation>Запрещенный XML</translation>
    </message>
    <message>
        <source>See Other Host</source>
        <translation>Смотри другой хост</translation>
    </message>
    <message>
        <source>System Shutdown</source>
        <translation>Выключение системы</translation>
    </message>
    <message>
        <source>Undefined Condition</source>
        <translation>Неопределённое условие</translation>
    </message>
    <message>
        <source>Unsupported Encoding</source>
        <translation>Неподдерживаемая кодировка</translation>
    </message>
    <message>
        <source>Unsupported Stanza Type</source>
        <translation>Неподдерживаемый формат XML-транзакции</translation>
    </message>
    <message>
        <source>Unsupported Version</source>
        <translation>Неподдерживаемая версия</translation>
    </message>
    <message>
        <source>XML Not Well Formed</source>
        <translation>XML сформирован неправильно</translation>
    </message>
    <message>
        <source>XMPP Streams Manager</source>
        <translation>Диспетчер XMPP потоков</translation>
    </message>
    <message>
        <source>Allows other modules to create XMPP streams and get access to them</source>
        <translation>Позволяет другим модулям создавать XMPP потоки и получать доступ к ним</translation>
    </message>
</context>
</TS>

==> vacuum-1.0.2-source.tar.gz: vacuum-1.0.2/src/translations/ru_RU/xmppstreams.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="en">
<context>
    <name>XmppStream</name>
    <message>
        <source>Password request</source>
        <translation>Запрос пароля</translation>
    </message>
    <message>
        <source>Enter password for &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Введите пароль для &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Connection not specified</source>
        <translation>Соединение не определено</translation>
    </message>
    <message>
        <source>XMPP connection timed out</source>
        <translation>Превышено время установки XMPP соединения</translation>
    </message>
    <message>
        <source>Failed to start connection</source>
        <translation>Не удалось запустить соединение</translation>
    </message>
</context>
<context>
    <name>XmppStreams</name>
    <message>
        <source>Bad Request Format</source>
        <translation>Неверный формат запроса</translation>
    </message>
    <message>
        <source>Bad Namespace Prefix</source>
        <translation>Неверный префикс пространства имён</translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation>Конфликт</translation>
    </message>
    <message>
        <source>Connection timeout</source>
        <translation>Превышено время ожидания соединения</translation>
    </message>
    <message>
        <source>Host Gone</source>
        <translation>Хост недоступен</translation>
    </message>
    <message>
        <source>Host Unknown</source>
        <translation>Неизвестный хост</translation>
    </message>
    <message>
        <source>Improper Addressing</source>
        <translation>Неправильная адресация</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <source>Invalid From</source>
        <translation>Недопустимый отправитель</translation>
    </message>
    <message>
        <source>Invalid Id</source>
        <translation>Недопустимый ID</translation>
    </message>
    <message>
        <source>Invalid Namespace</source>
        <translation>Недопустимое пространство имён</translation>
    </message>
    <message>
        <source>Invalid XML</source>
        <translation>Недопустимый XML</translation>
    </message>
    <message>
        <source>Not Authorized</source>
        <translation>Не авторизован</translation>
    </message>
    <message>
        <source>Policy Violation</source>
        <translation>Нарушение правил</translation>
    </message>
    <message>
        <source>Remote Connection Failed</source>
        <translation>Сбой удаленного соединения</translation>
    </message>
    <message>
        <source>Resource Constraint</source>
        <translation>Ограничение ресурса</translation>
    </message>
    <message>
        <source>Restricted XML</source>
        <translation>Запрещенный XML</translation>
    </message>
    <message>
        <source>See Other Host</source>
        <translation>Смотри другой хост</translation>
    </message>
    <message>
        <source>System Shutdown</source>
        <translation>Выключение системы</translation>
    </message>
    <message>
        <source>Undefined Condition</source>
        <translation>Неопределённое условие</translation>
    </message>
    <message>
        <source>Unsupported Encoding</source>
        <translation>Неподдерживаемая кодировка</translation>
    </message>
    <message>
        <source>Unsupported Stanza Type</source>
        <translation>Неподдерживаемый формат XML-транзакции</translation>
    </message>
    <message>
        <source>Unsupported Version</source>
        <translation>Неподдерживаемая версия</translation>
    </message>
    <message>
        <source>XML Not Well Formed</source>
        <translation>XML сформирован неправильно</translation>
    </message>
    <message>
        <source>XMPP Streams Manager</source>
        <translation>Диспетчер XMPP потоков</translation>
    </message>
    <message>
        <source>Allows other modules to create XMPP streams and get access to them</source>
        <translation>Позволяет другим модулям создавать XMPP потоки и получать доступ к ним</translation>
    </message>
</context>
</TS>
